Plots the trunk yaw angular velocity with the detected turns shaded and the sit-to-stand / turn-to-sit transitions marked.
Arguments
- report
An
itug_reportfrominstrumentedTUG().- title
Plot title.
Plots the trunk yaw angular velocity with the detected turns shaded and the sit-to-stand / turn-to-sit transitions marked.
An itug_report from instrumentedTUG().
Plot title.