Band-pass filters the signal to the tremor band and returns its root-mean- square amplitude (in the units of the input signal).
Usage
tremorAmplitude(signal, sampling_rate, band = c(3, 12), order = 4)Band-pass filters the signal to the tremor band and returns its root-mean- square amplitude (in the units of the input signal).
tremorAmplitude(signal, sampling_rate, band = c(3, 12), order = 4)