Node positions of a serial planar chain from a base, the fixed segment lengths and the ABSOLUTE segment angles (radians, from the x-axis).
Usage
forwardKinematics2D(angles, lengths, base = c(0, 0))Node positions of a serial planar chain from a base, the fixed segment lengths and the ABSOLUTE segment angles (radians, from the x-axis).
forwardKinematics2D(angles, lengths, base = c(0, 0))