Build a Gait Deviation Index feature basis from a normative reference
Source:R/gait-indices.R
gdiBasis.RdComputes the singular-value-decomposition feature basis of the normative feature population used to score the Gait Deviation Index (Schwartz & Rozumalski 2008), together with the control-population log-distance mean and standard deviation used to standardise the index.