ACL return-to-sport pipeline (limb symmetry index)
Source:R/pipelines-population.R
pipelineACLrts.RdComputes the Limb Symmetry Index (LSI) for a battery of functional tests and evaluates the return-to-sport (RTS) criterion that every LSI meets a threshold (default 90\ tests where a higher score is better, and inverted otherwise.